import 'package:dialer/features/home/home_page.dart';
import 'package:flutter/material.dart';
import 'package:dialer/features/contacts/contact_state.dart';
import 'globals.dart' as globals;
import 'package:dialer/services/cryptography/asymmetric_crypto_service.dart';
import 'package:provider/provider.dart';

void main() async {
  const stealthFlag = String.fromEnvironment('STEALTH', defaultValue: 'false');
  globals.isStealthMode = stealthFlag.toLowerCase() == 'true';

  // Initialize CryptographyService
  final AsymmetricCryptoService cryptoService = AsymmetricCryptoService();
  // Initialize default key pair
  await cryptoService.initializeDefaultKeyPair();

  runApp(
    MultiProvider(
      providers: [
        Provider<AsymmetricCryptoService>(
          create: (_) => cryptoService,
        ),
        // Add other providers here
      ],
      child: Dialer(),
    ),
  );
}

class Dialer extends StatelessWidget {
  const Dialer({super.key});

  @override
  Widget build(BuildContext context) {
    return ContactState(
      child: MaterialApp(
        theme: ThemeData(
          brightness: Brightness.dark
        ),
        home: SafeArea(child: MyHomePage()),
      )
    );
  }
}
